@@ -1,21 +1,21 @@
-from pyinaturalist.constants import JsonResponse, MultiInt
+from pyinaturalist.constants import API_V1, JsonResponse, MultiInt
 from pyinaturalist.converters import convert_all_timestamps
 from pyinaturalist.docs import document_request_params
 from pyinaturalist.docs import templates as docs
-from pyinaturalist.pagination import add_paginate_all
+from pyinaturalist.paginator import paginate_all
 from pyinaturalist.request_params import convert_rank_range
-from pyinaturalist.v1 import get_v1
+from pyinaturalist.session import get
 
 
-@document_request_params([docs._taxon_params, docs._taxon_id_params, docs._pagination])
-@add_paginate_all(method='page')
+@document_request_params(docs._taxon_params, docs._taxon_id_params, docs._pagination)
 def get_taxa(**params) -> JsonResponse:
-    """Given zero to many of following parameters, get taxa matching the search criteria.
+    """Search taxa
 
-    **API reference:** https://api.inaturalist.org/v1/docs/#!/Taxa/get_taxa
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /taxa <Taxa/get_taxa>`
 
     Example:
-
         >>> response = get_taxa(q='vespi', rank=['genus', 'family'])
         >>> pprint(response)
         [52747] Family: Vespidae (Hornets, Paper Wasps, Potter Wasps, and Allies)
@@ -33,19 +33,23 @@ def get_taxa(**params) -> JsonResponse:
         Response dict containing taxon records
     """
     params = convert_rank_range(params)
-    response = get_v1('taxa', **params)
-    taxa = response.json()
+    if params.get('page') == 'all':
+        taxa = paginate_all(get, f'{API_V1}/taxa', **params)
+    else:
+        taxa = get(f'{API_V1}/taxa', **params).json()
+
     taxa['results'] = convert_all_timestamps(taxa['results'])
     return taxa
 
 
 def get_taxa_by_id(taxon_id: MultiInt, **params) -> JsonResponse:
-    """Get one or more taxa by ID.
+    """Get one or more taxa by ID
 
-    **API reference:** https://api.inaturalist.org/v1/docs/#!/Taxa/get_taxa_id
+    .. rubric:: Notes
+
+    * API reference: :v1:`GET /taxa/{id} <Taxa/get_taxa_id>`
 
     Example:
-
         >>> response = get_taxa_by_id(343248)
         >>> basic_fields = ['preferred_common_name', 'observations_count', 'wikipedia_url', 'wikipedia_summary']
         >>> print({f: response['results'][0][f] for f in basic_fields})
@@ -67,23 +71,22 @@ def get_taxa_by_id(taxon_id: MultiInt, **params) -> JsonResponse:
     Returns:
         Response dict containing taxon records
     """
-    response = get_v1('taxa', ids=taxon_id, **params)
+    response = get(f'{API_V1}/taxa', ids=taxon_id, **params)
     taxa = response.json()
     taxa['results'] = convert_all_timestamps(taxa['results'])
     return taxa
 
 
-@document_request_params([docs._taxon_params])
+@document_request_params(docs._taxon_params)
 def get_taxa_autocomplete(**params) -> JsonResponse:
     """Given a query string, return taxa with names starting with the search term
 
-    **API reference:** https://api.inaturalist.org/v1/docs/#!/Taxa/get_taxa_autocomplete
+    .. rubric:: Notes
 
-    **Note:** There appears to currently be a bug in the API that causes ``per_page`` to not have
-    any effect.
+    * API reference: :v1:`GET /taxa/autocomplete <Taxa/get_taxa_autocomplete>`
+    * There appears to currently be a bug in the API that causes ``per_page`` to not have any effect.
 
     Example:
-
         Get just the name of the first matching taxon:
 
         >>> response = get_taxa_autocomplete(q='vespi')
@@ -121,5 +124,27 @@ def get_taxa_autocomplete(**params) -> JsonResponse:
         Response dict containing taxon records
     """
     params = convert_rank_range(params)
-    response = get_v1('taxa/autocomplete', **params)
+    response = get(f'{API_V1}/taxa/autocomplete', **params)
     return response.json()
+
+
+def get_taxa_map_layers(taxon_id: int, **params) -> JsonResponse:
+    """Get some additional taxon metadata, including:
+    * GBIF taxon ID and URL
+    * Whether the taxon has range data and/or listed places
+
+    Example:
+        >>> response = get_taxa_map_layers(343248)
+
+        .. admonition:: Example Response
+            :class: toggle
+
+            .. literalinclude:: ../sample_data/get_taxa_map_layers.json
+                :language: JSON
+
+    Args:
+        taxon_id: iNaturalist taxon ID. Only one value is allowed.
+    """
+    response = get(f'{API_V1}/taxa/{taxon_id}/map_layers', **params).json()
+    response['gbif_url'] = f'https://www.gbif.org/species/{response["gbif_id"]}'
+    return response
