@@ -10,10 +10,11 @@ from os.path import join
 from unittest.mock import MagicMock, patch
 
 import pytest
-from requests import Session
+from requests_cache import DO_NOT_CACHE, BaseCache
 
 from pyinaturalist import enable_logging
 from pyinaturalist.constants import SAMPLE_DATA_DIR
+from pyinaturalist.session import ClientSession
 
 # If ipdb is installed, register it as the default debugger
 try:
@@ -43,13 +44,25 @@ MOCK_CREDS_OAUTH = {
 enable_logging('DEBUG')
 
 
+class TestSession(ClientSession):
+    """Session class to use for tests, which disables rate-limiting and caching"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.limiter = MagicMock()
+        self.cache = BaseCache(expire_after=DO_NOT_CACHE)
+
+
 @pytest.fixture(scope='function', autouse=True)
-def patch_cached_session():
-    """Use a regular requests.Session to disable request caching and rate-limiting during tests"""
-    with patch('pyinaturalist.session.get_local_session', return_value=Session()), patch(
-        'pyinaturalist.client.ClientSession', Session
-    ):
+def patch_session(request):
+    """Disable request caching and rate-limiting during tests"""
+    if 'enable_client_session' in request.keywords:
         yield
+    else:
+        with patch('pyinaturalist.session.get_local_session', return_value=TestSession()), patch(
+            'pyinaturalist.auth.get_local_session', return_value=TestSession()
+        ), patch('pyinaturalist.client.ClientSession', TestSession):
+            yield
 
 
 def get_module_functions(module):
