@@ -8,7 +8,7 @@ from requests_cache import CachedResponse
 from rich.console import Console
 from rich.table import Table
 
-from pyinaturalist.constants import API_V0_BASE_URL
+from pyinaturalist.constants import API_V0
 from pyinaturalist.formatters import *
 from test.sample_data import *
 
@@ -76,7 +76,7 @@ def test_pprint(response):
 PRINTED_OBSERVATION = """
 Observation(
     id=16227955,
-    created_at='2018-09-05 00:00:00+01:00',
+    created_at='2018-09-05 14:31:08+02:00',
     captive=False,
     community_taxon_id=493595,
     description='',
@@ -90,7 +90,7 @@ Observation(
     num_identification_agreements=2,
     num_identification_disagreements=0,
     obscured=False,
-    observed_on='2018-09-05 14:06:00+01:00',
+    observed_on='2018-09-05 14:06:00+02:00',
     outlinks=[{'source': 'GBIF', 'url': 'http://www.gbif.org/occurrence/1914197587'}],
     owners_identification_from_vision=True,
     place_guess='54 rue des Badauds',
@@ -148,12 +148,12 @@ def test_pretty_print():
 def test_format_request():
     request = Request(
         method='GET',
-        url=API_V0_BASE_URL,
+        url=API_V0,
         headers={'Accept': 'application/json', 'Authorization': 'password123'},
         json={'client_secret': 'password123'},
     ).prepare()
     request_str = format_request(request)
-    assert API_V0_BASE_URL in request_str
+    assert API_V0 in request_str
     assert 'Accept: application/json' in request_str
     assert 'password123' not in request_str
 
